@@ -5,7 +5,7 @@ describe 'cinder::backend::rbd' do
   let(:title) {'rbd-ssd'}
 
   let :facts do
-    @default_facts.merge({})
+    OSDefaults.get_facts({})
   end
 
   let :req_params do
@@ -17,7 +17,11 @@ describe 'cinder::backend::rbd' do
       :rbd_ceph_conf                    => '/foo/boo/zoo/ceph.conf',
       :rbd_flatten_volume_from_snapshot => true,
       :volume_tmp_dir                   => '<SERVICE DEFAULT>',
-      :rbd_max_clone_depth              => '0'
+      :rbd_max_clone_depth              => '0',
+      :rados_connect_timeout            => '<SERVICE DEFAULT>',
+      :rados_connection_interval        => '<SERVICE DEFAULT>',
+      :rados_connection_retries         => '<SERVICE DEFAULT>',
+      :rbd_store_chunk_size             => '<SERVICE DEFAULT>'
     }
   end
 
@@ -28,7 +32,7 @@ describe 'cinder::backend::rbd' do
   end
 
   let :facts do
-    {:osfamily => 'Debian'}
+    @default_facts.merge({:osfamily => 'Debian'})
   end
 
   describe 'rbd backend volume driver' do
@@ -43,8 +47,12 @@ describe 'cinder::backend::rbd' do
       is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_user").with_value(req_params[:rbd_user])
       is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_secret_uuid").with_value(req_params[:rbd_secret_uuid])
       is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/backend_host").with_value('rbd:'"#{req_params[:rbd_pool]}")
+      is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connect_timeout").with_value(req_params[:rados_connect_timeout])
+      is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connection_interval").with_value(req_params[:rados_connection_interval])
+      is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connection_retries").with_value(req_params[:rados_connection_retries])
+      is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_store_chunk_size").with_value(req_params[:rbd_store_chunk_size])
       is_expected.to contain_file('/etc/init/cinder-volume.override').with(:ensure => 'present')
-      is_expected.to contain_file_line('set initscript env').with(
+      is_expected.to contain_file_line('set initscript env rbd-ssd').with(
         :line    => /env CEPH_ARGS=\"--id test\"/,
         :path    => '/etc/init/cinder-volume.override',
         :notify  => 'Service[cinder-volume]')
@@ -54,7 +62,7 @@ describe 'cinder::backend::rbd' do
       let :pre_condition do
         "cinder::backend::rbd { 'ceph2':
            rbd_pool => 'volumes2',
-           rbd_user => 'test'
+           rbd_user => 'test2'
          }"
       end
       it { is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/volume_driver").with_value('cinder.volume.drivers.rbd.RBDDriver') }
@@ -62,7 +70,7 @@ describe 'cinder::backend::rbd' do
       it { is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_user").with_value(req_params[:rbd_user]) }
       it { is_expected.to contain_cinder_config("ceph2/volume_driver").with_value('cinder.volume.drivers.rbd.RBDDriver') }
       it { is_expected.to contain_cinder_config("ceph2/rbd_pool").with_value('volumes2') }
-      it { is_expected.to contain_cinder_config("ceph2/rbd_user").with_value('test') }
+      it { is_expected.to contain_cinder_config("ceph2/rbd_user").with_value('test2') }
     end
 
     context 'rbd backend with additional configuration' do
@@ -93,7 +101,7 @@ describe 'cinder::backend::rbd' do
 
   describe 'with RedHat' do
     let :facts do
-        { :osfamily => 'RedHat' }
+        @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     let :params do
@@ -107,7 +115,7 @@ describe 'cinder::backend::rbd' do
     end
 
     it 'should configure RedHat init override' do
-      is_expected.to contain_file_line('set initscript env').with(
+      is_expected.to contain_file_line('set initscript env rbd-ssd').with(
         :line    => /export CEPH_ARGS=\"--id test\"/,
         :path    => '/etc/sysconfig/openstack-cinder-volume',
         :notify  => 'Service[cinder-volume]')
